# Yet Another ECS CTL tool

```
pip install ya-ecs-ctl

```

Adds binary:


```
ecs

```

```

Usage: main.py [OPTIONS] COMMAND [ARGS]...

Options:
  --help  Show this message and exit.

Commands:
  clusters                  Display Clusters Info
  container-instances       List container Instances
  create                    Create Service
  delete                    Delete Service
  drain-container-instance  Set a container Instance to DRAIN
  ec2-instances             List ec2 Instances
  list                      List Services
  redeploy                  Force redeployment of a Service
  register                  Register task definition
  scale                     Scale Service
  start-task                Start task
  stop-task                 Stop task
  switch-cluster            Switch Default Cluster
  tasks                     List Tasks for Service
  update                    Update Service


```

## Alternatives..

